@@ -2,18 +2,23 @@ use v5.10.0;
 use warnings;
 package JMAP::Tester::Role::Result;
 # ABSTRACT: the kind of thing that you get back for a request
-$JMAP::Tester::Role::Result::VERSION = '0.003';
+$JMAP::Tester::Role::Result::VERSION = '0.004';
 use Moo::Role;
 
 #pod =head1 OVERVIEW
 #pod
 #pod This is the role consumed by the class of any object returned by JMAP::Tester's
-#pod C<request> method.  Its only guarantee, for now, is an C<is_success> method.
+#pod C<request> method.  Its only guarantee, for now, is an C<is_success> method,
+#pod and an C<http_response> method.
 #pod
 #pod =cut
 
 requires 'is_success';
 
+has http_response => (
+  is => 'ro',
+);
+
 1;
 
 __END__
@@ -28,12 +33,13 @@ JMAP::Tester::Role::Result - the kind of thing that you get back for a request
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 OVERVIEW
 
 This is the role consumed by the class of any object returned by JMAP::Tester's
-C<request> method.  Its only guarantee, for now, is an C<is_success> method.
+C<request> method.  Its only guarantee, for now, is an C<is_success> method,
+and an C<http_response> method.
 
 =head1 AUTHOR
 
